"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthorizationProvider = void 0;
const tslib_1 = require("tslib");
const authorization_1 = require("@loopback/authorization");
const core_1 = require("@loopback/core");
const security_1 = require("@loopback/security");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
let AuthorizationProvider = class AuthorizationProvider {
    value() {
        return this.authorize.bind(this);
    }
    async authorize(authorizationCtx, metadata) {
        var _a, _b;
        // Bypass authorize if metadata have *
        if (metadata.resource === '*') {
            return authorization_1.AuthorizationDecision.ALLOW;
        }
        let currentUser;
        if (authorizationCtx.principals.length > 0) {
            const user = lodash_1.default.pick(authorizationCtx.principals[0], [
                'id',
                'name',
                'role',
                'permissions',
                'userTenantId',
            ]);
            if (!user)
                return authorization_1.AuthorizationDecision.DENY;
            currentUser = {
                [security_1.securityId]: user.id,
                name: user.name,
                role: user.role,
                permissions: user.permissions,
                id: user.id,
                userTenantId: user.userTenantId,
            };
        }
        else {
            return authorization_1.AuthorizationDecision.DENY;
        }
        if (!currentUser.role) {
            return authorization_1.AuthorizationDecision.DENY;
        }
        const allPermissions = [
            ...currentUser.permissions,
            ...currentUser.role.permissions,
        ];
        if (metadata.resource && allPermissions.includes((_a = metadata.resource) !== null && _a !== void 0 ? _a : '')) {
            return authorization_1.AuthorizationDecision.ALLOW;
        }
        let roleIsAllowed = false;
        if ((_b = metadata === null || metadata === void 0 ? void 0 : metadata.allowedRoles) === null || _b === void 0 ? void 0 : _b.includes(currentUser.role.roleType.toString())) {
            roleIsAllowed = true;
        }
        if (roleIsAllowed) {
            return authorization_1.AuthorizationDecision.ALLOW;
        }
        return authorization_1.AuthorizationDecision.DENY;
    }
};
AuthorizationProvider = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT })
], AuthorizationProvider);
exports.AuthorizationProvider = AuthorizationProvider;
//# sourceMappingURL=authorization.service.js.map